pub async fn build_analytics_indexer(
config: IndexerConfig,
indexer_args: IndexerArgs,
client_args: ClientArgs,
metrics: Metrics,
registry: Registry,
) -> Result<Service>Expand description
Build and run an analytics indexer, returning a Service handle.
The returned Service integrates store shutdown - when the service shuts down gracefully, it will wait for all pending uploads to complete.